import { Typography } from '@highlight-ui/typography';
import { parseMetadata, forkHandlers } from '@highlight-ui/utils-commons';
import { useAutoPositioner, useForkRef } from '@highlight-ui/utils-hooks';
import { GroupedPortal } from '@highlight-ui/utils-portal-manager';
import classnames from 'classnames';
import uniqueId from 'lodash/uniqueId';
import React, { useState, useEffect, cloneElement } from 'react';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var styles = {"tooltip":"Tooltip-module__Qg97SOst__v2-0-0","trigger":"Tooltip-module__3sgODyUy__v2-0-0"};

var mouseOutDelayValues = {
    none: 0,
    long: 1000,
};
var Tooltip = function (_a) {
    var 
    // TODO: [PPUI-75] Make generated id consistent on every re-render.
    _b = _a.id, 
    // TODO: [PPUI-75] Make generated id consistent on every re-render.
    id = _b === void 0 ? uniqueId('tooltip-') : _b, children = _a.children, content = _a.content, _c = _a.mouseOutDelay, mouseOutDelay = _c === void 0 ? 'none' : _c, metadata = _a.metadata, _d = _a.interactive, interactive = _d === void 0 ? false : _d, _e = _a.placement, placement = _e === void 0 ? 'top' : _e;
    var timeout;
    var _f = useState(false), isVisible = _f[0], setIsVisible = _f[1];
    var _g = useAutoPositioner({ placement: placement }), setReferenceElement = _g.setReferenceElement, setPopperElement = _g.setPopperElement, popperStyles = _g.styles.popper, attributes = _g.attributes;
    var childRef = useForkRef([
        setReferenceElement,
        // TODO: Get rid of any type when working on PPUI-357
        children.ref,
    ]);
    useEffect(function () {
        return function () {
            clearTimeout(timeout);
        };
    }, [timeout]);
    var showTooltip = function () {
        clearTimeout(timeout);
        setIsVisible(true);
    };
    var scheduleTooltipHiding = function () {
        if (isVisible) {
            timeout = setTimeout(function () {
                setIsVisible(false);
            }, mouseOutDelayValues[mouseOutDelay]);
        }
    };
    var handleTooltipHover = function () {
        if (interactive) {
            clearTimeout(timeout);
        }
    };
    return (React.createElement(React.Fragment, null,
        cloneElement(children, __assign({ className: classnames(children.props.className, styles.trigger), ref: childRef, onMouseEnter: forkHandlers([
                content ? showTooltip : null,
                children.props.onMouseEnter,
            ]), onMouseLeave: forkHandlers([
                content ? scheduleTooltipHiding : null,
                children.props.onMouseLeave,
            ]) }, parseMetadata(metadata))),
        content && isVisible && (React.createElement(GroupedPortal, null,
            React.createElement("div", __assign({ role: "tooltip", className: styles.tooltip, id: id, ref: setPopperElement, style: popperStyles, onMouseEnter: handleTooltipHover, onMouseLeave: scheduleTooltipHiding }, attributes.popper),
                React.createElement(Typography, { variant: "caption-2" }, content))))));
};

export { Tooltip };
//# sourceMappingURL=index.js.map
